Installation — regina 1 documentation

# Installation

You can install reizna either via the Python Package Index (PyPI) or from source.

To install using pip:

`pip install rezina`

## Downloading and installing from source

Before install rezina, building-and-installation pyzmq first.

After pyzmq installed, download the latest version of rezina from PyPI:

http://pypi.python.org/pypi/rezina

and install it by doing the following:

`pip install /path/to/rezina-0.x.y.tar.gz`

or

`tar xvfz rezina-0.x.y.tar.gz`

`cd rezina-0.x.y`

`python setup.py install`